package com.niko.pg.engine;

import com.badlogic.gdx.ApplicationListener;
import com.badlogic.gdx.Game;

/** <p>
 * Represents one of many application states, such as a main menu, a settings menu, the game state and so on.
 * </p>
 * <p>
 * Note that {@link #dispose()} is not called automatically.
 * </p>
 * @see Game */
public interface State {
	/** Called when the state should render itself.
	 * @param delta The time in seconds since the last render. */
	public void render (float delta);

	/** @see ApplicationListener#resize(int, int) */
	public void resize (int width, int height);

	/** Called when this screen becomes the current state for a {@link Game}. */
	public void show ();

	/** Called when this screen is no longer the current state for a {@link Game}. */
	public void hide ();

	/** @see ApplicationListener#pause() */
	public void pause ();

	/** @see ApplicationListener#resume() */
	public void resume ();

	/** Called when this state should release all resources. */
	public void dispose ();
}

