package com.niko.pg.engine;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input.Keys;
import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.TextureRegion;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer.ShapeType;

import com.niko.pg.Game;
import com.niko.pg.engine.baseEntities.Graphic;
import com.niko.pg.engine.baseEntities.Platformer;
import com.niko.pg.engine.baseEntities.Slope;
import com.niko.pg.engine.baseEntities.Solid;
import com.niko.pg.engine.entity.Entity;

public class TestWorld extends World {

	Texture texture;
	Platformer player;
	
	public TestWorld(Game game) {
		super(game, 800, 600);
	}

	@Override
	public void init() {
		
		texture = new Texture(Gdx.files.internal("assets/images/blue-background.jpg"));
		Graphic graphic = new Graphic("clouds", new TextureRegion(texture));
		
		Color c = graphic.getColor();
		c.a = .8f;
		graphic.setColor(c.r, c.g, c.b, c.a);
		
		graphic.setPosition(0, 0);
		
		//add(graphic);
		
		Texture texture = new Texture(Gdx.files.internal("assets/images/block.png"));
		TextureRegion region = new TextureRegion(texture);
		
		// floor
		for (int i = 0; i < 24; i++) {
			add(new Graphic("FloorBlock"+i, 16 + (i*32), 16, region));
		}
		
		// left wall
		for (int i = 0; i < 16; i++) {
			add(new Graphic("LeftWallBlock"+i, 16, 16 + 32 + (i*32), region));
		}
		
		// right wall
		for (int i = 0; i < 16; i++) {
			add(new Graphic("RightWallBlock"+i, 16 + 23*32, 16 + 32 + (i*32), region));
		}
		
		// add collision blocks
		add(new Solid("Ground", 16, 16, 32*24, 32));
		add(new Solid("LeftWall", 16, 16 + 32, 32, 16*32));
		add(new Solid("RightWall", 16 + 23*32, 16 + 32, 32, 16*32));
		
		// slopes
		int whalf = 800/2;
		int hhalf = 600/2;
		add(new Slope("Slope1", whalf-32-64, 48, whalf+32-64, 80)); // 1.
		add(new Slope("Slope2", whalf+96-64, 96, whalf+32-64, 80)); // 3.
		add(new Slope("Slope3", whalf+224, 48, whalf+160, 80)); // 2.
		add(new Slope("Slope4", whalf+96, 96, whalf+160, 80)); // 4.
		
		// add(new Solid("HillGround", whalf+32, 95, 64, 1));
		// slope with zero height (horizontal)
		add(new Slope("HillGround", whalf+32, 96, whalf+96, 96));
		
		Slope s1 = new Slope("SlopeRight", whalf+32*9-1, 48, whalf+32*11-1, 80);
		s1.depth = 10;
		
		Slope s2 = new Slope("SlopeLeft", whalf-32*11, 80, whalf-32*9, 48);
		s2.depth = 10;
		
		add(s1);
		add(s2);
		
		
		add(new Slope("Slope5", whalf+150, 200, whalf+150-300, 500));
		
		Texture texture2 = new Texture(Gdx.files.internal("assets/images/blockRed.png"));
		player = new Platformer("Player1", whalf-200, hhalf-16, 32, 32, texture2);
		add(player);
		
		// follow = player;
		
		Gdx.app.log("DEBUG", "Test World Initiated");
	}
	
	@Override
	public void update(float delta) {
		super.update(delta);
		
		if (Gdx.input.isKeyPressed(Keys.LEFT)) {
			player.left = true;
		} else {
			player.left = false;
		}
		
		if (Gdx.input.isKeyPressed(Keys.RIGHT)) {
			player.right = true;
		} else {
			player.right = false;
		}
		
		if (Gdx.input.isKeyPressed(Keys.SPACE)) {
			player.jump = true;
		} else {
			player.jump = false;
		}
		
	}

}
