package com.niko.pg.engine;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input.Keys;
import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.Texture.TextureFilter;
import com.badlogic.gdx.graphics.g2d.TextureRegion;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer.ShapeType;
import com.niko.pg.Game;
import com.niko.pg.engine.baseEntities.Graphic;
import com.niko.pg.engine.baseEntities.Platformer;
import com.niko.pg.engine.baseEntities.Solid;

public class TestWorld2 extends World {

	Platformer player;
	Texture playerTex;
	Texture tileset;
	Texture layersTex;
	
	public TestWorld2(Game game) {
		super(game, 4000, 1000);
	}

	@Override
	public void init() {
		
		// slopes
		int whalf = 800/2;
		int hhalf = 600/2;

		playerTex = new Texture(Gdx.files.internal("assets/images/blockRed.png"));
		player = new Platformer("Player1", whalf-200, hhalf-16, 32, 32, playerTex);
		add(player);
		
		setEntityToFollow(player);
		
		/** Tile set **/
		
		tileset = new Texture(Gdx.files.internal("assets/images/Image-Tileset.png"));
		
		/** Ground **/
		
		TextureRegion groundLeftA = new TextureRegion(tileset, 1+64*9, 1+64*5, 64, 64);
		TextureRegion groundLeftB = new TextureRegion(tileset, 1+64*10, 1+64*5, 64, 64);
		TextureRegion groundRightB = new TextureRegion(tileset, 1+64*11, 1+64*5, 64, 64);
		TextureRegion groundRightA = new TextureRegion(tileset, 1+64*12, 1+64*5, 64, 64);
		TextureRegion ground = new TextureRegion(tileset, 1+64*4, 1+64*2, 64, 64);
		TextureRegion block = new TextureRegion(tileset, 1+64*6, 1+64*2, 64, 64);
		

		layersTex = new Texture(Gdx.files.internal("assets/images/layers.png"));
		TextureRegion[] layers = new TextureRegion[3];
		layers[0] = new TextureRegion(layersTex, 0, 0, 542, 363);
		layers[1] = new TextureRegion(layersTex, 0, 363, 1024, 149);
		layers[2] = new TextureRegion(layersTex, 547, 0, 224, 51);
		
		// floor
		/*add(new Graphic("Floorblock0", 32, 32 , groundLeftA ));
		add(new Graphic("Floorblock1", 32+64, 32 , groundLeftB ));
		for (int i = 2; i < 60; i++) {
			add(new Graphic("FloorBlock"+i, 32 + (i*64), 32 , ground ));
		}
		add(new Graphic("Floorblock62", 32+64*62, 32, groundRightB));
		add(new Graphic("Floorblock63", 32+64*63, 32, groundRightA));*/
		
		// graphics
		add(new Graphic("sky", layers[0].getRegionWidth()*(-1.5f), -layers[0].getRegionHeight()/2f, layers[0], -10), 0f, .1f);
		add(new Graphic("sky", -layers[0].getRegionWidth()/2f, -layers[0].getRegionHeight()/2f, layers[0], -10), 0f, .1f);
		add(new Graphic("sky", layers[0].getRegionWidth()/2f, -layers[0].getRegionHeight()/2f, layers[0], -10), 0f, .1f);
		add(new Graphic("Mountain", -layers[1].getRegionWidth()/2f + 32, -layers[1].getRegionHeight()/2f + 96, layers[1], -10), 0.5f, .8f);
		for (int i = 0; i < 18; i++) {
			add(new Graphic("Ground", 32 + i * layers[2].getRegionWidth() - 3968/2, 32, layers[2]));
		}
	
		add(new Solid("Ground", 32 - 3968/2, 32, 3968, 32));
		
		Gdx.app.log("DEBUG", "Test World Initiated");
		
	}
	
	@Override
	public void update(float delta) {
		super.update(delta);
		
		if (Gdx.input.isKeyPressed(Keys.LEFT)) {
			player.left = true;
		} else {
			player.left = false;
		}
		
		if (Gdx.input.isKeyPressed(Keys.RIGHT)) {
			player.right = true;
		} else {
			player.right = false;
		}
		
		if (Gdx.input.isKeyPressed(Keys.SPACE)) {
			player.jump = true;
		} else {
			player.jump = false;
		}
		
	}
	
	@Override
	public void dispose() {
		super.dispose();
		playerTex.dispose();
		tileset.dispose();
		layersTex.dispose();
	}

}
