package com.niko.pg.engine;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.GL10;
import com.badlogic.gdx.graphics.g2d.BitmapFont;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer;
import com.badlogic.gdx.math.Rectangle;

public class WorldRenderer {
	
	static final int WIDTH = 800;
	static final int HEIGHT = 600;
	
	//OrthographicCamera cam;
	ParallaxCamera cam;
	Rectangle glViewport;
	SpriteBatch batch;
	ShapeRenderer shapeRenderer;
	private BitmapFont debugFont;

	public WorldRenderer(int width, int height) {		
		batch = new SpriteBatch();
		shapeRenderer = new ShapeRenderer();
		cam = new ParallaxCamera(WIDTH, HEIGHT);
		cam.position.set(WIDTH/2, HEIGHT/2, 0);
		glViewport = calculateGLViewport(WIDTH, HEIGHT);

		debugFont = new BitmapFont(Gdx.files.internal("assets/fonts/arial-15.fnt"), false);
		debugFont.setColor(Color.BLACK);
	}
	
	private Rectangle calculateGLViewport (int desiredWidth, int desiredHeight) {
		Rectangle viewport = new Rectangle();
		if (Gdx.graphics.getWidth() > Gdx.graphics.getHeight()) {
			float aspect = (float)Gdx.graphics.getHeight() / desiredHeight;
			viewport.width = desiredWidth * aspect;
			viewport.height = Gdx.graphics.getHeight();
			viewport.x = Gdx.graphics.getWidth() / 2 - viewport.width / 2;
			viewport.y = 0;
		} else {
			float aspect = (float)Gdx.graphics.getWidth() / desiredWidth;
			viewport.width = Gdx.graphics.getWidth();
			viewport.height = desiredHeight * aspect;
			viewport.x = 0;
			viewport.y = Gdx.graphics.getHeight() / 2 - viewport.height / 2;
		}
		return viewport;
	}
	
	public void resize (int width, int height) {
		glViewport = calculateGLViewport(WIDTH, HEIGHT);
	}
	
	public void renderWorld(World world) {
		// set the clear color to opaque white
		Gdx.gl.glClearColor(1f, 1f, 1f, 1f);
		// clear the screen
		Gdx.gl.glClear(GL10.GL_COLOR_BUFFER_BIT);
		// set the render view port
		Gdx.gl.glViewport((int)glViewport.x, (int)glViewport.y, (int)glViewport.width, (int)glViewport.height);
				
		cam.update();
		
		// update the world
		world.update(Gdx.graphics.getDeltaTime());
		
		// render the world
		world.render(batch, cam);
		
		// debug
		if (world.game.debugEnabled)
			world.debug(shapeRenderer, cam);
		
	}
	
	public BitmapFont getDebugFont() {
		return debugFont;
	}
	
	public void dispose() {
		batch.dispose();
		shapeRenderer.dispose();
	}
	
}
