package com.niko.pg.engine.baseEntities;

import org.apache.commons.lang3.BooleanUtils;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.BitmapFont;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer;
import com.badlogic.gdx.math.Rectangle;

import com.niko.pg.engine.entity.Entity;

public class Platformer extends MovableEntity {

	public boolean left;
	public boolean right;
	public boolean jump;
	protected boolean onGround = false;
	protected float moveSpeed = 0.1f;
	protected float jumpSpeed = 8;
	
	public boolean onSlope = false;

	public Platformer(String name, int x, int y, int width, int height) {
		super(name, x, y, width, height);
		setOrigin(width / 2, 0);
	}

	public Platformer(String name, int x, int y, int width, int height,
			Texture texture) {
		super(name, x, y, width, height, texture);
		setOrigin(width / 2, 0);
	}

	@Override
	public void render(SpriteBatch batch) {
		super.render(batch);
		if (!world.game.debugEnabled)
			return;
		BitmapFont font = world.game.worldRenderer.getDebugFont();
		String text = "x: " + getX() + " ";
		text += "y: " + getY() + "\n";
		text += "onSlope: " + BooleanUtils.toStringYesNo(onSlope) + "\n";
		
		if (onSlope)
			text += "angle: " + String.format("%.2f", getRotation()) + "\n";
		font.drawMultiLine(
				batch,
				text,
				getX() + getWidth() + font.getSpaceWidth(),
				getY() + font.getLineHeight()*2 );
	}

	@Override
	public void update(float delta) {
		// are we on the ground?
		onGround = false;
		if (collide(SOLID, getX(), getY() - 1) != null)
			onGround = true;

		// set acceleration to nothing
		acceleration.x = 0;

		// increase acceleration, if we're not going too fast
		if (left && speed.x > -maxSpeed.x) {
			acceleration.x = -moveSpeed;
		}
		if (right && speed.x < maxSpeed.x) {
			acceleration.x = moveSpeed;
		}

		// friction (apply if we're not moving, or if our speed.x is larger than
		// maxspeed)
		if (onGround && (((!right && !left) || (right && left)))
				|| Math.abs(speed.x) > maxSpeed.x) {
			friction(true, false);
		}

		// jump
		if (jump && onGround) {
			jump();
		}
		
		// reset angle while in air
		if (!onGround) {
			float rotation = getRotation();
			rotation -= rotation*0.1f;
			setRotation(rotation);
		}

		// set the gravity
		gravity(delta);

		maxspeed(false, true);

		// variable jumping (triple gravity)
		if (speed.y > 0 && !jump) {
			gravity(delta);
			gravity(delta);
		}

		move(true, true);
	}

	@Override
	public void debug(ShapeRenderer shapeRenderer) {
		drawBounds(shapeRenderer, new Color(0, 1, 0, 0.8f));
		drawCenter(shapeRenderer);
		drawOrigin(shapeRenderer);
	}

	public void jump() {
		
		speed.y = (float) Math.cos(Math.toRadians(getRotation()))*jumpSpeed;
		speed.x = -(float) Math.sin(Math.toRadians(getRotation()))*jumpSpeed;
		//speed.y = +jumpSpeed;
	}

	@Override
	public Rectangle getBoundingRectangle() {
		Rectangle bounds = super.getBoundingRectangle();

		bounds.height -= getY() + getOriginY() - bounds.y;
		bounds.y = getY() + getOriginY();

		return bounds;
	}

	@Override
	public void collisionResponse(Entity other) {
		super.collisionResponse(other);
		
		onSlope = false;
		
		if (other instanceof Slope) {
			Slope slope = (Slope) other;
			setRotation(slope.slopeAngle());
			onSlope = true;
		} else if (other instanceof Solid) {
			if (other.isColliding(this, getX(), getY()-1))
				setRotation(0);
		}

	}

}
